[GitHub Pages](https://jameskabbes.github.io/py_starter)<br>
[PyPI](https://pypi.org/project/kabbes-py-starter)

# py_starter
Helpful python starter functions for various repository use

<br>

# Installation
`pip install kabbes_py_starter`

<br>

# Usage
For more in-depth documentation, read the information provided on the Pages. Or better yet, read the source code.

```python
import py_starter as ps
```

```python
ps.print_for_loop( ['Apple','Strawberry','Banana'] )
```

```
>>> 
1. Apple
2. Strawberry
3. Banana
```

```python
ps.merge_two_dicts( {'A':'Alpha','C':'Nothing'}, {'B':'Bravo':'C':'Charlie'} )
```

```
>>> {'A':'Alpha','B':'Bravo','C':'Charlie'}
```

<br>

# Author
James Kabbes
